@@ -61,7 +61,7 @@ Vue.component('edit-field', {
         example: { }
     },
     data: function () {
-        var schemaType, fieldType = 'text', inputMode = 'text',
+        var schemaType, fieldType = 'text', inputMode = 'text', children = [],
             pattern = this.schema.pattern;
 
         if ( Array.isArray( this.schema.type ) ) {
@@ -119,7 +119,17 @@ Vue.component('edit-field', {
                 inputMode = 'numeric';
             }
         }
-
+        else if (schemaType == 'array') {
+            fieldType = 'array';
+            children = (this.value || []).map(function (v, ix) {
+              return ({
+                name: this.name + "-"+ix,
+                example: this.schema.items.example,
+                required: false, valid: this.valid,
+                schema: this.schema.items,
+                value: v
+              })}, this);
+        }
         return {
             fieldType: fieldType,
             pattern: pattern,
@@ -131,12 +141,28 @@ Vue.component('edit-field', {
             writeonly: this.schema.writeOnly,
             inputMode: inputMode,
             _value: this.value,
-            showHtml: false
+            showHtml: false,
+            children: children
         };
     },
     methods: {
         input: function () {
+            if(this.children.length){
+                this.value = this.children.map(function(e){return e.value;}).filter(function(e){return e;});
+                this.$data._value = this.value;
+            }
             this.$emit( 'input', this.$data._value );
+        },
+        addChild: function () {
+            this.children.push({
+                name: this.name + "-"+(this.children.length+1),
+                example: this.schema.items.example,
+                required: false, valid: true,
+                schema: this.schema.items
+              });
+        },
+        removeChild: function (ix) {
+            this.children.splice(ix,1);
         }
     },
     computed: {
@@ -149,6 +175,10 @@ Vue.component('edit-field', {
     watch: {
         value: function () {
             this.$data._value = this.value;
+        },
+        children: function() {
+            this.value = this.children.map(function(e){return e.value;}).filter(function(e){return e;});
+            this.$emit('input', this.value);
         }
     }
 });
@@ -675,7 +705,7 @@ var app = window.Yancy = new Vue({
             var schema = this.currentSchema,
                 item = {};
             for ( var k in schema.properties ) {
-                item[k] = schema.properties[k].default || null;
+                item[k] = schema.properties[k].default === undefined ? null : schema.properties[k].default;
             }
             return item;
         },
